@@ -52,6 +52,9 @@ class BaseServer:
     def init(self):
         pass
 
+    def status(self):
+        run_shell(f"supervisorctl -c {self.manage.manage_conf_path} status")
+
     def stop(self):
         run_shell(f"supervisorctl -c {self.manage.manage_conf_path} stop {self.server_name}")
 
